hotspot/src/share/vm/ci/ciMethod.cpp
changeset 6418 6671edbd230e
parent 6187 4fa7845f7c14
child 6453 970dc585ab63
--- a/hotspot/src/share/vm/ci/ciMethod.cpp	Mon Aug 23 09:09:36 2010 -0700
+++ b/hotspot/src/share/vm/ci/ciMethod.cpp	Wed Aug 25 05:27:54 2010 -0700
@@ -922,12 +922,12 @@
 
 // ------------------------------------------------------------------
 // ciMethod::instructions_size
 // This is a rough metric for "fat" methods, compared
 // before inlining with InlineSmallCode.
 // The CodeBlob::instructions_size accessor includes
 // junk like exception handler, stubs, and constant table,
 // which are not highly relevant to an inlined method.
 // So we use the more specific accessor nmethod::code_size.
 int ciMethod::instructions_size() {
   GUARDED_VM_ENTRY(
     nmethod* code = get_methodOop()->code();
@@ -939,7 +939,7 @@
         (TieredCompilation && code->compiler() != NULL && code->compiler()->is_c1())) {
       return 0;
     }
-    return code->code_end() - code->verified_entry_point();
+    return code->insts_end() - code->verified_entry_point();
   )
 }
@@ -922,12 +922,12 @@
 // ------------------------------------------------------------------
 // ciMethod::instructions_size
-// This is a rough metric for "fat" methods, compared
-// before inlining with InlineSmallCode.
-// The CodeBlob::instructions_size accessor includes
-// junk like exception handler, stubs, and constant table,
-// which are not highly relevant to an inlined method.
-// So we use the more specific accessor nmethod::code_size.
+//
+// This is a rough metric for "fat" methods, compared before inlining
+// with InlineSmallCode.  The CodeBlob::code_size accessor includes
+// junk like exception handler, stubs, and constant table, which are
+// not highly relevant to an inlined method.  So we use the more
+// specific accessor nmethod::insts_size.
 int ciMethod::instructions_size() {
   GUARDED_VM_ENTRY(